summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2024-06-28 23:12:42 +0200
committerCarl Hetherington <cth@carlh.net>2024-08-17 12:57:31 +0200
commit8e43142645252daeeaccbad7b9f3ed746c4b2382 (patch)
tree6c029caa9f0c961087ec6145da0bbbb8abf17146 /src
parent06c28c700f0a398a3289c4adfa83ceb2d0fc999d (diff)
{,Interop,SMPTE}SubtitleAsset -> {,Interop,SMPTE}TextAsset.
Diffstat (limited to 'src')
-rw-r--r--src/asset_factory.cc4
-rw-r--r--src/combine.cc4
-rw-r--r--src/dcp.cc12
-rw-r--r--src/interop_text_asset.cc (renamed from src/interop_subtitle_asset.cc)42
-rw-r--r--src/interop_text_asset.h (renamed from src/interop_subtitle_asset.h)18
-rw-r--r--src/reel.cc10
-rw-r--r--src/reel_interop_text_asset.cc2
-rw-r--r--src/reel_interop_text_asset.h12
-rw-r--r--src/reel_smpte_text_asset.cc4
-rw-r--r--src/reel_smpte_text_asset.h14
-rw-r--r--src/reel_text_asset.cc7
-rw-r--r--src/reel_text_asset.h14
-rw-r--r--src/smpte_text_asset.cc (renamed from src/smpte_subtitle_asset.cc)42
-rw-r--r--src/smpte_text_asset.h (renamed from src/smpte_subtitle_asset.h)20
-rw-r--r--src/text_asset.cc (renamed from src/subtitle_asset.cc)62
-rw-r--r--src/text_asset.h (renamed from src/subtitle_asset.h)20
-rw-r--r--src/text_asset_internal.cc (renamed from src/subtitle_asset_internal.cc)6
-rw-r--r--src/text_asset_internal.h (renamed from src/subtitle_asset_internal.h)8
-rw-r--r--src/verify.cc30
-rw-r--r--src/verify.h4
-rw-r--r--src/wscript14
21 files changed, 174 insertions, 175 deletions
diff --git a/src/asset_factory.cc b/src/asset_factory.cc
index 26811366..652e1e31 100644
--- a/src/asset_factory.cc
+++ b/src/asset_factory.cc
@@ -42,7 +42,7 @@
#include "compose.hpp"
#include "mono_j2k_picture_asset.h"
#include "mono_mpeg2_picture_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "sound_asset.h"
#include "stereo_j2k_picture_asset.h"
#include "stereo_j2k_picture_asset.h"
@@ -93,7 +93,7 @@ dcp::asset_factory (boost::filesystem::path path, bool ignore_incorrect_picture_
case ASDCP::ESS_JPEG_2000_S:
return make_shared<StereoJ2KPictureAsset>(path);
case ASDCP::ESS_TIMED_TEXT:
- return make_shared<SMPTESubtitleAsset>(path);
+ return make_shared<SMPTETextAsset>(path);
case ASDCP::ESS_DCDATA_DOLBY_ATMOS:
return make_shared<AtmosAsset>(path);
default:
diff --git a/src/combine.cc b/src/combine.cc
index b7a625f0..74456bfb 100644
--- a/src/combine.cc
+++ b/src/combine.cc
@@ -45,7 +45,7 @@
#include "exceptions.h"
#include "filesystem.h"
#include "font_asset.h"
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "raw_convert.h"
#include <boost/filesystem.hpp>
#include <set>
@@ -139,7 +139,7 @@ dcp::combine (
continue;
}
- auto sub = dynamic_pointer_cast<dcp::InteropSubtitleAsset>(j);
+ auto sub = dynamic_pointer_cast<dcp::InteropTextAsset>(j);
if (sub) {
/* Interop fonts are really fiddly. The font files are assets (in the ASSETMAP)
* and also linked from the font XML by filename. We have to fix both these things,
diff --git a/src/dcp.cc b/src/dcp.cc
index 2ab74545..92c5cd88 100644
--- a/src/dcp.cc
+++ b/src/dcp.cc
@@ -49,7 +49,7 @@
#include "exceptions.h"
#include "filesystem.h"
#include "font_asset.h"
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "metadata.h"
#include "mono_j2k_picture_asset.h"
#include "mono_mpeg2_picture_asset.h"
@@ -58,7 +58,7 @@
#include "raw_convert.h"
#include "reel_asset.h"
#include "reel_text_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "sound_asset.h"
#include "stereo_j2k_picture_asset.h"
#include "util.h"
@@ -222,7 +222,7 @@ DCP::read (vector<dcp::VerificationNote>* notes, bool ignore_incorrect_picture_m
if (
pkl_type == remove_parameters(CPL::static_pkl_type(standard)) ||
- pkl_type == remove_parameters(InteropSubtitleAsset::static_pkl_type(standard))) {
+ pkl_type == remove_parameters(InteropTextAsset::static_pkl_type(standard))) {
auto p = new xmlpp::DomParser;
try {
p->parse_file(dcp::filesystem::fix_long_path(path).string());
@@ -244,14 +244,14 @@ DCP::read (vector<dcp::VerificationNote>* notes, bool ignore_incorrect_picture_m
if (standard == Standard::SMPTE && notes) {
notes->push_back (VerificationNote(VerificationNote::Type::ERROR, VerificationNote::Code::MISMATCHED_STANDARD));
}
- other_assets.push_back (make_shared<InteropSubtitleAsset>(path));
+ other_assets.push_back (make_shared<InteropTextAsset>(path));
}
} else if (
*pkl_type == remove_parameters(J2KPictureAsset::static_pkl_type(standard)) ||
*pkl_type == remove_parameters(MPEG2PictureAsset::static_pkl_type(standard)) ||
*pkl_type == remove_parameters(SoundAsset::static_pkl_type(standard)) ||
*pkl_type == remove_parameters(AtmosAsset::static_pkl_type(standard)) ||
- *pkl_type == remove_parameters(SMPTESubtitleAsset::static_pkl_type(standard))
+ *pkl_type == remove_parameters(SMPTETextAsset::static_pkl_type(standard))
) {
bool found_threed_marked_as_twod = false;
@@ -544,7 +544,7 @@ DCP::assets (bool ignore_unresolved) const
auto o = j->asset_ref().asset();
assets.push_back (o);
/* More Interop special-casing */
- auto sub = dynamic_pointer_cast<InteropSubtitleAsset>(o);
+ auto sub = dynamic_pointer_cast<InteropTextAsset>(o);
if (sub) {
add_to_container(assets, sub->font_assets());
}
diff --git a/src/interop_subtitle_asset.cc b/src/interop_text_asset.cc
index a4594207..31d00712 100644
--- a/src/interop_subtitle_asset.cc
+++ b/src/interop_text_asset.cc
@@ -32,8 +32,8 @@
*/
-/** @file src/interop_subtitle_asset.cc
- * @brief InteropSubtitleAsset class
+/** @file src/interop_text_asset.cc
+ * @brief InteropTextAsset class
*/
@@ -44,9 +44,9 @@
#include "font_asset.h"
#include "file.h"
#include "interop_load_font_node.h"
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "raw_convert.h"
-#include "subtitle_asset_internal.h"
+#include "text_asset_internal.h"
#include "subtitle_image.h"
#include "util.h"
#include "warnings.h"
@@ -70,8 +70,8 @@ using boost::optional;
using namespace dcp;
-InteropSubtitleAsset::InteropSubtitleAsset (boost::filesystem::path file)
- : SubtitleAsset (file)
+InteropTextAsset::InteropTextAsset(boost::filesystem::path file)
+ : TextAsset(file)
{
_raw_xml = dcp::file_to_string (file);
@@ -102,14 +102,14 @@ InteropSubtitleAsset::InteropSubtitleAsset (boost::filesystem::path file)
}
-InteropSubtitleAsset::InteropSubtitleAsset ()
+InteropTextAsset::InteropTextAsset()
{
}
string
-InteropSubtitleAsset::xml_as_string () const
+InteropTextAsset::xml_as_string() const
{
xmlpp::Document doc;
auto root = doc.create_root_node ("DCSubtitle");
@@ -133,7 +133,7 @@ InteropSubtitleAsset::xml_as_string () const
void
-InteropSubtitleAsset::add_font (string load_id, dcp::ArrayData data)
+InteropTextAsset::add_font(string load_id, dcp::ArrayData data)
{
_fonts.push_back (Font(load_id, make_uuid(), data));
auto const uri = String::compose("font_%1.ttf", _load_font_nodes.size());
@@ -142,13 +142,13 @@ InteropSubtitleAsset::add_font (string load_id, dcp::ArrayData data)
bool
-InteropSubtitleAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
+InteropTextAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
{
- if (!SubtitleAsset::equals (other_asset, options, note)) {
+ if (!TextAsset::equals (other_asset, options, note)) {
return false;
}
- auto other = dynamic_pointer_cast<const InteropSubtitleAsset> (other_asset);
+ auto other = dynamic_pointer_cast<const InteropTextAsset> (other_asset);
if (!other) {
return false;
}
@@ -183,7 +183,7 @@ InteropSubtitleAsset::equals(shared_ptr<const Asset> other_asset, EqualityOption
vector<shared_ptr<LoadFontNode>>
-InteropSubtitleAsset::load_font_nodes () const
+InteropTextAsset::load_font_nodes() const
{
vector<shared_ptr<LoadFontNode>> lf;
copy (_load_font_nodes.begin(), _load_font_nodes.end(), back_inserter (lf));
@@ -192,7 +192,7 @@ InteropSubtitleAsset::load_font_nodes () const
void
-InteropSubtitleAsset::write (boost::filesystem::path p) const
+InteropTextAsset::write(boost::filesystem::path p) const
{
File f(p, "wb");
if (!f) {
@@ -230,7 +230,7 @@ InteropSubtitleAsset::write (boost::filesystem::path p) const
* a list of font ID, load ID and data.
*/
void
-InteropSubtitleAsset::resolve_fonts (vector<shared_ptr<Asset>> assets)
+InteropTextAsset::resolve_fonts(vector<shared_ptr<Asset>> assets)
{
for (auto asset: assets) {
auto font = dynamic_pointer_cast<FontAsset>(asset);
@@ -256,7 +256,7 @@ InteropSubtitleAsset::resolve_fonts (vector<shared_ptr<Asset>> assets)
vector<shared_ptr<Asset>>
-InteropSubtitleAsset::font_assets()
+InteropTextAsset::font_assets()
{
vector<shared_ptr<Asset>> assets;
for (auto const& i: _fonts) {
@@ -268,7 +268,7 @@ InteropSubtitleAsset::font_assets()
vector<shared_ptr<const Asset>>
-InteropSubtitleAsset::font_assets() const
+InteropTextAsset::font_assets() const
{
vector<shared_ptr<const Asset>> assets;
for (auto const& i: _fonts) {
@@ -280,7 +280,7 @@ InteropSubtitleAsset::font_assets() const
void
-InteropSubtitleAsset::add_to_assetmap (AssetMap& asset_map, boost::filesystem::path root) const
+InteropTextAsset::add_to_assetmap(AssetMap& asset_map, boost::filesystem::path root) const
{
Asset::add_to_assetmap(asset_map, root);
@@ -295,7 +295,7 @@ InteropSubtitleAsset::add_to_assetmap (AssetMap& asset_map, boost::filesystem::p
void
-InteropSubtitleAsset::add_to_pkl (shared_ptr<PKL> pkl, boost::filesystem::path root) const
+InteropTextAsset::add_to_pkl(shared_ptr<PKL> pkl, boost::filesystem::path root) const
{
Asset::add_to_pkl (pkl, root);
@@ -310,7 +310,7 @@ InteropSubtitleAsset::add_to_pkl (shared_ptr<PKL> pkl, boost::filesystem::path r
void
-InteropSubtitleAsset::set_font_file (string load_id, boost::filesystem::path file)
+InteropTextAsset::set_font_file(string load_id, boost::filesystem::path file)
{
for (auto& i: _fonts) {
if (i.load_id == load_id) {
@@ -327,7 +327,7 @@ InteropSubtitleAsset::set_font_file (string load_id, boost::filesystem::path fil
vector<string>
-InteropSubtitleAsset::unresolved_fonts() const
+InteropTextAsset::unresolved_fonts() const
{
vector<string> unresolved;
for (auto load_font_node: _load_font_nodes) {
diff --git a/src/interop_subtitle_asset.h b/src/interop_text_asset.h
index ad1c68a7..363b1f27 100644
--- a/src/interop_subtitle_asset.h
+++ b/src/interop_text_asset.h
@@ -32,16 +32,16 @@
*/
-/** @file src/interop_subtitle_asset.h
- * @brief InteropSubtitleAsset class
+/** @file src/interop_text_asset.h
+ * @brief InteropTextAsset class
*/
-#ifndef LIBDCP_INTEROP_SUBTITLE_ASSET_H
-#define LIBDCP_INTEROP_SUBTITLE_ASSET_H
+#ifndef LIBDCP_INTEROP_TEXT_ASSET_H
+#define LIBDCP_INTEROP_TEXT_ASSET_H
-#include "subtitle_asset.h"
+#include "text_asset.h"
#include "subtitle_standard.h"
#include <boost/filesystem.hpp>
@@ -52,16 +52,16 @@ namespace dcp {
class InteropLoadFontNode;
-/** @class InteropSubtitleAsset
+/** @class InteropTextAsset
* @brief A set of subtitles to be read and/or written in the Inter-Op format
*
* Inter-Op subtitles are sometimes known as CineCanvas.
*/
-class InteropSubtitleAsset : public SubtitleAsset
+class InteropTextAsset : public TextAsset
{
public:
- InteropSubtitleAsset ();
- explicit InteropSubtitleAsset (boost::filesystem::path file);
+ InteropTextAsset();
+ explicit InteropTextAsset(boost::filesystem::path file);
bool equals (
std::shared_ptr<const Asset>,
diff --git a/src/reel.cc b/src/reel.cc
index 3eb81e1d..fa20cba9 100644
--- a/src/reel.cc
+++ b/src/reel.cc
@@ -40,7 +40,7 @@
#include "decrypted_kdm.h"
#include "decrypted_kdm_key.h"
#include "equality_options.h"
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "mono_j2k_picture_asset.h"
#include "j2k_picture_asset.h"
#include "reel.h"
@@ -52,10 +52,10 @@
#include "reel_sound_asset.h"
#include "reel_stereo_picture_asset.h"
#include "reel_text_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "sound_asset.h"
#include "stereo_j2k_picture_asset.h"
-#include "subtitle_asset.h"
+#include "text_asset.h"
#include "util.h"
#include <libxml++/nodes/element.h>
#include <stdint.h>
@@ -408,7 +408,7 @@ Reel::resolve_refs (vector<shared_ptr<Asset>> assets)
/* Interop subtitle handling is all special cases */
if (_main_subtitle->asset_ref().resolved()) {
- auto iop = dynamic_pointer_cast<InteropSubtitleAsset> (_main_subtitle->asset_ref().asset());
+ auto iop = dynamic_pointer_cast<InteropTextAsset>(_main_subtitle->asset_ref().asset());
if (iop) {
iop->resolve_fonts (assets);
}
@@ -420,7 +420,7 @@ Reel::resolve_refs (vector<shared_ptr<Asset>> assets)
/* Interop subtitle handling is all special cases */
if (i->asset_ref().resolved()) {
- auto iop = dynamic_pointer_cast<InteropSubtitleAsset> (i->asset_ref().asset());
+ auto iop = dynamic_pointer_cast<InteropTextAsset>(i->asset_ref().asset());
if (iop) {
iop->resolve_fonts (assets);
}
diff --git a/src/reel_interop_text_asset.cc b/src/reel_interop_text_asset.cc
index b5e20f78..62211b6d 100644
--- a/src/reel_interop_text_asset.cc
+++ b/src/reel_interop_text_asset.cc
@@ -52,7 +52,7 @@ using boost::optional;
using namespace dcp;
-ReelInteropTextAsset::ReelInteropTextAsset(TextType type, std::shared_ptr<SubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
+ReelInteropTextAsset::ReelInteropTextAsset(TextType type, std::shared_ptr<TextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
: ReelTextAsset(type, asset, edit_rate, intrinsic_duration, entry_point)
{
diff --git a/src/reel_interop_text_asset.h b/src/reel_interop_text_asset.h
index 88cdeaae..428f0fd5 100644
--- a/src/reel_interop_text_asset.h
+++ b/src/reel_interop_text_asset.h
@@ -37,7 +37,7 @@
*/
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "reel_text_asset.h"
@@ -50,15 +50,15 @@ namespace dcp {
class ReelInteropTextAsset : public ReelTextAsset
{
public:
- ReelInteropTextAsset(TextType type, std::shared_ptr<SubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
+ ReelInteropTextAsset(TextType type, std::shared_ptr<TextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
explicit ReelInteropTextAsset (std::shared_ptr<const cxml::Node>);
- std::shared_ptr<const InteropSubtitleAsset> interop_asset () const {
- return asset_of_type<const InteropSubtitleAsset>();
+ std::shared_ptr<const InteropTextAsset> interop_asset() const {
+ return asset_of_type<const InteropTextAsset>();
}
- std::shared_ptr<InteropSubtitleAsset> interop_asset () {
- return asset_of_type<InteropSubtitleAsset>();
+ std::shared_ptr<InteropTextAsset> interop_asset() {
+ return asset_of_type<InteropTextAsset>();
}
xmlpp::Element* write_to_cpl(xmlpp::Element* node, Standard standard) const override;
diff --git a/src/reel_smpte_text_asset.cc b/src/reel_smpte_text_asset.cc
index 68f85586..48694651 100644
--- a/src/reel_smpte_text_asset.cc
+++ b/src/reel_smpte_text_asset.cc
@@ -38,7 +38,7 @@
#include "reel_smpte_text_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "warnings.h"
LIBDCP_DISABLE_WARNINGS
#include <libxml++/libxml++.h>
@@ -53,7 +53,7 @@ using boost::optional;
using namespace dcp;
-ReelSMPTETextAsset::ReelSMPTETextAsset(TextType type, shared_ptr<SMPTESubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
+ReelSMPTETextAsset::ReelSMPTETextAsset(TextType type, shared_ptr<SMPTETextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
: ReelTextAsset(type, asset, edit_rate, intrinsic_duration, entry_point)
{
diff --git a/src/reel_smpte_text_asset.h b/src/reel_smpte_text_asset.h
index 24344a3a..9a1c78a9 100644
--- a/src/reel_smpte_text_asset.h
+++ b/src/reel_smpte_text_asset.h
@@ -38,13 +38,13 @@
#include "reel_text_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
namespace dcp {
-class SMPTESubtitleAsset;
+class SMPTETextAsset;
/** @class ReelSMPTETextAsset
@@ -53,15 +53,15 @@ class SMPTESubtitleAsset;
class ReelSMPTETextAsset : public ReelTextAsset
{
public:
- ReelSMPTETextAsset(TextType type, std::shared_ptr<SMPTESubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
+ ReelSMPTETextAsset(TextType type, std::shared_ptr<SMPTETextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
explicit ReelSMPTETextAsset(std::shared_ptr<const cxml::Node>);
- std::shared_ptr<const SMPTESubtitleAsset> smpte_asset () const {
- return asset_of_type<const SMPTESubtitleAsset>();
+ std::shared_ptr<const SMPTETextAsset> smpte_asset() const {
+ return asset_of_type<const SMPTETextAsset>();
}
- std::shared_ptr<SMPTESubtitleAsset> smpte_asset () {
- return asset_of_type<SMPTESubtitleAsset>();
+ std::shared_ptr<SMPTETextAsset> smpte_asset() {
+ return asset_of_type<SMPTETextAsset>();
}
xmlpp::Element* write_to_cpl(xmlpp::Element* node, Standard standard) const override;
diff --git a/src/reel_text_asset.cc b/src/reel_text_asset.cc
index 87a8ae58..09749946 100644
--- a/src/reel_text_asset.cc
+++ b/src/reel_text_asset.cc
@@ -39,8 +39,7 @@
#include "language_tag.h"
#include "reel_text_asset.h"
-#include "smpte_subtitle_asset.h"
-#include "subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "warnings.h"
LIBDCP_DISABLE_WARNINGS
#include <libxml++/libxml++.h>
@@ -54,10 +53,10 @@ using boost::optional;
using namespace dcp;
-ReelTextAsset::ReelTextAsset(TextType type, std::shared_ptr<SubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
+ReelTextAsset::ReelTextAsset(TextType type, std::shared_ptr<TextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
: ReelFileAsset (
asset,
- dynamic_pointer_cast<SMPTESubtitleAsset>(asset) ? dynamic_pointer_cast<SMPTESubtitleAsset>(asset)->key_id() : boost::none,
+ dynamic_pointer_cast<SMPTETextAsset>(asset) ? dynamic_pointer_cast<SMPTETextAsset>(asset)->key_id() : boost::none,
asset->id(),
edit_rate,
intrinsic_duration,
diff --git a/src/reel_text_asset.h b/src/reel_text_asset.h
index cf904921..35efe941 100644
--- a/src/reel_text_asset.h
+++ b/src/reel_text_asset.h
@@ -44,7 +44,7 @@
#include "language_tag.h"
#include "reel_asset.h"
#include "reel_file_asset.h"
-#include "subtitle_asset.h"
+#include "text_asset.h"
#include "text_type.h"
@@ -55,7 +55,7 @@ struct verify_invalid_language2;
namespace dcp {
-class SubtitleAsset;
+class TextAsset;
/** @class ReelTextAsset
@@ -64,15 +64,15 @@ class SubtitleAsset;
class ReelTextAsset : public ReelFileAsset
{
public:
- ReelTextAsset(TextType type, std::shared_ptr<SubtitleAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
+ ReelTextAsset(TextType type, std::shared_ptr<TextAsset> asset, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
explicit ReelTextAsset(std::shared_ptr<const cxml::Node>);
- std::shared_ptr<const SubtitleAsset> asset () const {
- return asset_of_type<const SubtitleAsset>();
+ std::shared_ptr<const TextAsset> asset() const {
+ return asset_of_type<const TextAsset>();
}
- std::shared_ptr<SubtitleAsset> asset () {
- return asset_of_type<SubtitleAsset>();
+ std::shared_ptr<TextAsset> asset() {
+ return asset_of_type<TextAsset>();
}
bool equals(std::shared_ptr<const ReelTextAsset>, EqualityOptions const&, NoteHandler) const;
diff --git a/src/smpte_subtitle_asset.cc b/src/smpte_text_asset.cc
index 4f611583..987715cb 100644
--- a/src/smpte_subtitle_asset.cc
+++ b/src/smpte_text_asset.cc
@@ -32,8 +32,8 @@
*/
-/** @file src/smpte_subtitle_asset.cc
- * @brief SMPTESubtitleAsset class
+/** @file src/smpte_text_asset.cc
+ * @brief SMPTETextAsset class
*/
@@ -45,7 +45,7 @@
#include "filesystem.h"
#include "raw_convert.h"
#include "smpte_load_font_node.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "subtitle_image.h"
#include "util.h"
#include "warnings.h"
@@ -79,7 +79,7 @@ static string const subtitle_smpte_ns_2010 = "http://www.smpte-ra.org/schemas/42
static string const subtitle_smpte_ns_2014 = "http://www.smpte-ra.org/schemas/428-7/2014/DCST";
-SMPTESubtitleAsset::SMPTESubtitleAsset(SubtitleStandard standard)
+SMPTETextAsset::SMPTETextAsset(SubtitleStandard standard)
: MXF(Standard::SMPTE)
, _edit_rate (24, 1)
, _time_code_rate (24)
@@ -90,8 +90,8 @@ SMPTESubtitleAsset::SMPTESubtitleAsset(SubtitleStandard standard)
}
-SMPTESubtitleAsset::SMPTESubtitleAsset (boost::filesystem::path file)
- : SubtitleAsset (file)
+SMPTETextAsset::SMPTETextAsset(boost::filesystem::path file)
+ : TextAsset (file)
{
auto xml = make_shared<cxml::Document>("SubtitleReel");
@@ -169,7 +169,7 @@ SMPTESubtitleAsset::SMPTESubtitleAsset (boost::filesystem::path file)
void
-SMPTESubtitleAsset::parse_xml (shared_ptr<cxml::Document> xml)
+SMPTETextAsset::parse_xml(shared_ptr<cxml::Document> xml)
{
if (xml->namespace_uri() == subtitle_smpte_ns_2007) {
_subtitle_standard = SubtitleStandard::SMPTE_2007;
@@ -222,7 +222,7 @@ SMPTESubtitleAsset::parse_xml (shared_ptr<cxml::Document> xml)
void
-SMPTESubtitleAsset::read_mxf_resources (shared_ptr<ASDCP::TimedText::MXFReader> reader, shared_ptr<DecryptionContext> dec)
+SMPTETextAsset::read_mxf_resources(shared_ptr<ASDCP::TimedText::MXFReader> reader, shared_ptr<DecryptionContext> dec)
{
ASDCP::TimedText::TimedTextDescriptor descriptor;
reader->FillTimedTextDescriptor (descriptor);
@@ -284,7 +284,7 @@ SMPTESubtitleAsset::read_mxf_resources (shared_ptr<ASDCP::TimedText::MXFReader>
void
-SMPTESubtitleAsset::read_mxf_descriptor (shared_ptr<ASDCP::TimedText::MXFReader> reader)
+SMPTETextAsset::read_mxf_descriptor(shared_ptr<ASDCP::TimedText::MXFReader> reader)
{
ASDCP::TimedText::TimedTextDescriptor descriptor;
reader->FillTimedTextDescriptor (descriptor);
@@ -301,7 +301,7 @@ SMPTESubtitleAsset::read_mxf_descriptor (shared_ptr<ASDCP::TimedText::MXFReader>
void
-SMPTESubtitleAsset::set_key (Key key)
+SMPTETextAsset::set_key(Key key)
{
/* See if we already have a key; if we do, and we have a file, we'll already
have read that file.
@@ -345,7 +345,7 @@ SMPTESubtitleAsset::set_key (Key key)
vector<shared_ptr<LoadFontNode>>
-SMPTESubtitleAsset::load_font_nodes () const
+SMPTETextAsset::load_font_nodes() const
{
vector<shared_ptr<LoadFontNode>> lf;
copy (_load_font_nodes.begin(), _load_font_nodes.end(), back_inserter(lf));
@@ -354,7 +354,7 @@ SMPTESubtitleAsset::load_font_nodes () const
bool
-SMPTESubtitleAsset::valid_mxf (boost::filesystem::path file)
+SMPTETextAsset::valid_mxf(boost::filesystem::path file)
{
Kumu::FileReaderFactory factory;
ASDCP::TimedText::MXFReader reader(factory);
@@ -366,7 +366,7 @@ SMPTESubtitleAsset::valid_mxf (boost::filesystem::path file)
string
-SMPTESubtitleAsset::xml_as_string () const
+SMPTETextAsset::xml_as_string() const
{
xmlpp::Document doc;
auto root = doc.create_root_node ("SubtitleReel");
@@ -403,7 +403,7 @@ SMPTESubtitleAsset::xml_as_string () const
void
-SMPTESubtitleAsset::write (boost::filesystem::path p) const
+SMPTETextAsset::write(boost::filesystem::path p) const
{
EncryptionContext enc (key(), Standard::SMPTE);
@@ -508,13 +508,13 @@ SMPTESubtitleAsset::write (boost::filesystem::path p) const
}
bool
-SMPTESubtitleAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
+SMPTETextAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
{
- if (!SubtitleAsset::equals (other_asset, options, note)) {
+ if (!TextAsset::equals (other_asset, options, note)) {
return false;
}
- auto other = dynamic_pointer_cast<const SMPTESubtitleAsset>(other_asset);
+ auto other = dynamic_pointer_cast<const SMPTETextAsset>(other_asset);
if (!other) {
note (NoteType::ERROR, "Subtitles are in different standards");
return false;
@@ -587,7 +587,7 @@ SMPTESubtitleAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions
void
-SMPTESubtitleAsset::add_font (string load_id, dcp::ArrayData data)
+SMPTETextAsset::add_font(string load_id, dcp::ArrayData data)
{
string const uuid = make_uuid ();
_fonts.push_back (Font(load_id, uuid, data));
@@ -596,15 +596,15 @@ SMPTESubtitleAsset::add_font (string load_id, dcp::ArrayData data)
void
-SMPTESubtitleAsset::add (shared_ptr<Subtitle> s)
+SMPTETextAsset::add(shared_ptr<Subtitle> s)
{
- SubtitleAsset::add (s);
+ TextAsset::add(s);
_intrinsic_duration = latest_subtitle_out().as_editable_units_ceil(_edit_rate.numerator / _edit_rate.denominator);
}
string
-SMPTESubtitleAsset::schema_namespace() const
+SMPTETextAsset::schema_namespace() const
{
switch (_subtitle_standard) {
case SubtitleStandard::SMPTE_2007:
diff --git a/src/subtitle_asset.cc b/src/text_asset.cc
index 1cd4fc07..4ba3b623 100644
--- a/src/subtitle_asset.cc
+++ b/src/text_asset.cc
@@ -32,8 +32,8 @@
*/
-/** @file src/subtitle_asset.cc
- * @brief SubtitleAsset class
+/** @file src/text_asset.cc
+ * @brief TextAsset class
*/
@@ -42,10 +42,10 @@
#include "load_font_node.h"
#include "raw_convert.h"
#include "reel_asset.h"
-#include "subtitle_asset.h"
-#include "subtitle_asset_internal.h"
#include "subtitle_image.h"
#include "subtitle_string.h"
+#include "text_asset.h"
+#include "text_asset_internal.h"
#include "util.h"
#include "xml.h"
#include <asdcp/AS_DCP.h>
@@ -71,13 +71,13 @@ using boost::optional;
using namespace dcp;
-SubtitleAsset::SubtitleAsset ()
+TextAsset::TextAsset()
{
}
-SubtitleAsset::SubtitleAsset (boost::filesystem::path file)
+TextAsset::TextAsset(boost::filesystem::path file)
: Asset (file)
{
@@ -133,8 +133,8 @@ optional_number_attribute (xmlpp::Element const * node, string name)
}
-SubtitleAsset::ParseState
-SubtitleAsset::font_node_state (xmlpp::Element const * node, Standard standard) const
+TextAsset::ParseState
+TextAsset::font_node_state(xmlpp::Element const * node, Standard standard) const
{
ParseState ps;
@@ -169,7 +169,7 @@ SubtitleAsset::font_node_state (xmlpp::Element const * node, Standard standard)
}
void
-SubtitleAsset::position_align (SubtitleAsset::ParseState& ps, xmlpp::Element const * node) const
+TextAsset::position_align(TextAsset::ParseState& ps, xmlpp::Element const * node) const
{
auto hp = optional_number_attribute<float> (node, "HPosition");
if (!hp) {
@@ -210,8 +210,8 @@ SubtitleAsset::position_align (SubtitleAsset::ParseState& ps, xmlpp::Element con
}
-SubtitleAsset::ParseState
-SubtitleAsset::text_node_state (xmlpp::Element const * node) const
+TextAsset::ParseState
+TextAsset::text_node_state(xmlpp::Element const * node) const
{
ParseState ps;
@@ -228,8 +228,8 @@ SubtitleAsset::text_node_state (xmlpp::Element const * node) const
}
-SubtitleAsset::ParseState
-SubtitleAsset::image_node_state (xmlpp::Element const * node) const
+TextAsset::ParseState
+TextAsset::image_node_state(xmlpp::Element const * node) const
{
ParseState ps;
@@ -241,8 +241,8 @@ SubtitleAsset::image_node_state (xmlpp::Element const * node) const
}
-SubtitleAsset::ParseState
-SubtitleAsset::subtitle_node_state (xmlpp::Element const * node, optional<int> tcr) const
+TextAsset::ParseState
+TextAsset::subtitle_node_state(xmlpp::Element const * node, optional<int> tcr) const
{
ParseState ps;
ps.in = Time (string_attribute(node, "TimeIn"), tcr);
@@ -254,7 +254,7 @@ SubtitleAsset::subtitle_node_state (xmlpp::Element const * node, optional<int> t
Time
-SubtitleAsset::fade_time (xmlpp::Element const * node, string name, optional<int> tcr) const
+TextAsset::fade_time(xmlpp::Element const * node, string name, optional<int> tcr) const
{
auto const u = optional_string_attribute(node, name).get_value_or ("");
Time t;
@@ -276,7 +276,7 @@ SubtitleAsset::fade_time (xmlpp::Element const * node, string name, optional<int
void
-SubtitleAsset::parse_subtitles (xmlpp::Element const * node, vector<ParseState>& state, optional<int> tcr, Standard standard)
+TextAsset::parse_subtitles(xmlpp::Element const * node, vector<ParseState>& state, optional<int> tcr, Standard standard)
{
if (node->get_name() == "Font") {
state.push_back (font_node_state (node, standard));
@@ -393,7 +393,7 @@ SubtitleAsset::parse_subtitles (xmlpp::Element const * node, vector<ParseState>&
void
-SubtitleAsset::maybe_add_subtitle(
+TextAsset::maybe_add_subtitle(
string text,
vector<ParseState> const & parse_state,
float space_before,
@@ -553,7 +553,7 @@ SubtitleAsset::maybe_add_subtitle(
vector<shared_ptr<const Subtitle>>
-SubtitleAsset::subtitles () const
+TextAsset::subtitles() const
{
vector<shared_ptr<const Subtitle>> s;
for (auto i: _subtitles) {
@@ -564,7 +564,7 @@ SubtitleAsset::subtitles () const
vector<shared_ptr<const Subtitle>>
-SubtitleAsset::subtitles_during (Time from, Time to, bool starting) const
+TextAsset::subtitles_during(Time from, Time to, bool starting) const
{
vector<shared_ptr<const Subtitle>> s;
for (auto i: _subtitles) {
@@ -578,14 +578,14 @@ SubtitleAsset::subtitles_during (Time from, Time to, bool starting) const
void
-SubtitleAsset::add (shared_ptr<Subtitle> s)
+TextAsset::add(shared_ptr<Subtitle> s)
{
_subtitles.push_back (s);
}
Time
-SubtitleAsset::latest_subtitle_out () const
+TextAsset::latest_subtitle_out() const
{
Time t;
for (auto i: _subtitles) {
@@ -599,13 +599,13 @@ SubtitleAsset::latest_subtitle_out () const
bool
-SubtitleAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
+TextAsset::equals(shared_ptr<const Asset> other_asset, EqualityOptions const& options, NoteHandler note) const
{
if (!Asset::equals (other_asset, options, note)) {
return false;
}
- auto other = dynamic_pointer_cast<const SubtitleAsset> (other_asset);
+ auto other = dynamic_pointer_cast<const TextAsset> (other_asset);
if (!other) {
return false;
}
@@ -660,7 +660,7 @@ struct SubtitleSorter
void
-SubtitleAsset::pull_fonts (shared_ptr<order::Part> part)
+TextAsset::pull_fonts(shared_ptr<order::Part> part)
{
if (part->children.empty ()) {
return;
@@ -724,7 +724,7 @@ SubtitleAsset::pull_fonts (shared_ptr<order::Part> part)
* class because the differences between the two are fairly subtle.
*/
void
-SubtitleAsset::subtitles_as_xml (xmlpp::Element* xml_root, int time_code_rate, Standard standard) const
+TextAsset::subtitles_as_xml(xmlpp::Element* xml_root, int time_code_rate, Standard standard) const
{
auto sorted = _subtitles;
std::stable_sort(sorted.begin(), sorted.end(), SubtitleSorter());
@@ -824,7 +824,7 @@ SubtitleAsset::subtitles_as_xml (xmlpp::Element* xml_root, int time_code_rate, S
map<string, ArrayData>
-SubtitleAsset::font_data () const
+TextAsset::font_data() const
{
map<string, ArrayData> out;
for (auto const& i: _fonts) {
@@ -835,7 +835,7 @@ SubtitleAsset::font_data () const
map<string, boost::filesystem::path>
-SubtitleAsset::font_filenames () const
+TextAsset::font_filenames() const
{
map<string, boost::filesystem::path> out;
for (auto const& i: _fonts) {
@@ -852,7 +852,7 @@ SubtitleAsset::font_filenames () const
* (see DCP-o-matic bug #1689).
*/
void
-SubtitleAsset::fix_empty_font_ids ()
+TextAsset::fix_empty_font_ids()
{
bool have_empty = false;
vector<string> ids;
@@ -965,7 +965,7 @@ format_xml_node (xmlpp::Node const* node, State& state)
* to get all namespaces with the libxml++ API.
*/
string
-SubtitleAsset::format_xml(xmlpp::Document const& document, optional<pair<string, string>> xml_namespace)
+TextAsset::format_xml(xmlpp::Document const& document, optional<pair<string, string>> xml_namespace)
{
auto root = document.get_root_node();
@@ -997,7 +997,7 @@ SubtitleAsset::format_xml(xmlpp::Document const& document, optional<pair<string,
void
-SubtitleAsset::ensure_font(string load_id, dcp::ArrayData data)
+TextAsset::ensure_font(string load_id, dcp::ArrayData data)
{
if (std::find_if(_fonts.begin(), _fonts.end(), [load_id](Font const& font) { return font.load_id == load_id; }) == _fonts.end()) {
add_font(load_id, data);
diff --git a/src/subtitle_asset_internal.cc b/src/text_asset_internal.cc
index 39f68624..51821c78 100644
--- a/src/subtitle_asset_internal.cc
+++ b/src/text_asset_internal.cc
@@ -32,12 +32,12 @@
*/
-/** @file src/subtitle_asset_internal.cc
- * @brief Internal SubtitleAsset helpers
+/** @file src/text_asset_internal.cc
+ * @brief Internal TextAsset helpers
*/
-#include "subtitle_asset_internal.h"
+#include "text_asset_internal.h"
#include "subtitle_string.h"
#include "compose.hpp"
#include <cmath>
diff --git a/src/subtitle_asset_internal.h b/src/text_asset_internal.h
index 557db2e4..c8231219 100644
--- a/src/subtitle_asset_internal.h
+++ b/src/text_asset_internal.h
@@ -32,13 +32,13 @@
*/
-/** @file src/subtitle_asset_internal.h
- * @brief Internal SubtitleAsset helpers
+/** @file src/text_asset_internal.h
+ * @brief Internal TextAsset helpers
*/
-#ifndef LIBDCP_SUBTITLE_ASSET_INTERNAL_H
-#define LIBDCP_SUBTITLE_ASSET_INTERNAL_H
+#ifndef LIBDCP_TEXT_ASSET_INTERNAL_H
+#define LIBDCP_TEXT_ASSET_INTERNAL_H
#include "array_data.h"
diff --git a/src/verify.h b/src/verify.h
index e9a67f83..01ea0efe 100644
--- a/src/verify.h
+++ b/src/verify.h
@@ -59,7 +59,7 @@ namespace dcp {
class DCP;
-class SubtitleAsset;
+class TextAsset;
class VerificationNote
@@ -728,7 +728,7 @@ struct LinesCharactersResult
extern void verify_text_lines_and_characters(
- std::shared_ptr<const dcp::SubtitleAsset> asset,
+ std::shared_ptr<const dcp::TextAsset> asset,
int warning_length,
int error_length,
dcp::LinesCharactersResult* result
diff --git a/src/wscript b/src/wscript
index 2320fe0d..c61cd2e1 100644
--- a/src/wscript
+++ b/src/wscript
@@ -65,7 +65,7 @@ def build(bld):
h_align.cc
identity_transfer_function.cc
interop_load_font_node.cc
- interop_subtitle_asset.cc
+ interop_text_asset.cc
j2k_picture_asset.cc
j2k_picture_asset_writer.cc
j2k_transcode.cc
@@ -110,7 +110,7 @@ def build(bld):
s_gamut3_transfer_function.cc
search.cc
smpte_load_font_node.cc
- smpte_subtitle_asset.cc
+ smpte_text_asset.cc
sound_asset.cc
sound_asset_writer.cc
sound_frame.cc
@@ -118,8 +118,8 @@ def build(bld):
stereo_j2k_picture_asset_writer.cc
stereo_j2k_picture_frame.cc
subtitle.cc
- subtitle_asset.cc
- subtitle_asset_internal.cc
+ text_asset.cc
+ text_asset_internal.cc
subtitle_image.cc
subtitle_standard.cc
subtitle_string.cc
@@ -174,7 +174,7 @@ def build(bld):
h_align.h
identity_transfer_function.h
interop_load_font_node.h
- interop_subtitle_asset.h
+ interop_text_asset.h
ffmpeg_image.h
j2k_picture_asset.h
j2k_picture_asset_writer.h
@@ -225,7 +225,7 @@ def build(bld):
scope_guard.h
search.h
smpte_load_font_node.h
- smpte_subtitle_asset.h
+ smpte_text_asset.h
sound_asset.h
sound_asset_reader.h
sound_asset_writer.h
@@ -235,7 +235,7 @@ def build(bld):
stereo_j2k_picture_asset_writer.h
stereo_j2k_picture_frame.h
subtitle.h
- subtitle_asset.h
+ text_asset.h
subtitle_image.h
subtitle_standard.h
subtitle_string.h
diff --git a/src/smpte_subtitle_asset.h b/src/smpte_text_asset.h
index 26144fe1..b5b95c5d 100644
--- a/src/smpte_subtitle_asset.h
+++ b/src/smpte_text_asset.h
@@ -32,12 +32,12 @@
*/
-#ifndef LIBDCP_SMPTE_SUBTITLE_ASSET_H
-#define LIBDCP_SMPTE_SUBTITLE_ASSET_H
+#ifndef LIBDCP_SMPTE_TEXT_ASSET_H
+#define LIBDCP_SMPTE_TEXT_ASSET_H
-/** @file src/smpte_subtitle_asset.h
- * @brief SMPTESubtitleAsset class
+/** @file src/smpte_text_asset.h
+ * @brief SMPTETextAsset class
*/
@@ -45,7 +45,7 @@
#include "language_tag.h"
#include "local_time.h"
#include "mxf.h"
-#include "subtitle_asset.h"
+#include "text_asset.h"
#include "subtitle_standard.h"
#include <boost/filesystem.hpp>
@@ -69,18 +69,18 @@ namespace dcp {
class SMPTELoadFontNode;
-/** @class SMPTESubtitleAsset
+/** @class SMPTETextAsset
* @brief A set of subtitles to be read and/or written in the SMPTE format
*/
-class SMPTESubtitleAsset : public SubtitleAsset, public MXF
+class SMPTETextAsset : public TextAsset, public MXF
{
public:
- explicit SMPTESubtitleAsset(SubtitleStandard standard = SubtitleStandard::SMPTE_2014);
+ explicit SMPTETextAsset(SubtitleStandard standard = SubtitleStandard::SMPTE_2014);
- /** Construct a SMPTESubtitleAsset by reading an MXF or XML file
+ /** Construct a SMPTETextAsset by reading an MXF or XML file
* @param file Filename
*/
- explicit SMPTESubtitleAsset (boost::filesystem::path file);
+ explicit SMPTETextAsset(boost::filesystem::path file);
bool equals (
std::shared_ptr<const Asset>,
diff --git a/src/subtitle_asset.h b/src/text_asset.h
index 25758c2e..e1cb48c7 100644
--- a/src/subtitle_asset.h
+++ b/src/text_asset.h
@@ -32,13 +32,13 @@
*/
-/** @file src/subtitle_asset.h
- * @brief SubtitleAsset class
+/** @file src/text_asset.h
+ * @brief TextAsset class
*/
-#ifndef LIBDCP_SUBTITLE_ASSET_H
-#define LIBDCP_SUBTITLE_ASSET_H
+#ifndef LIBDCP_TEXT_ASSET_H
+#define LIBDCP_TEXT_ASSET_H
#include "array_data.h"
@@ -85,19 +85,19 @@ namespace order {
}
/** @class SubtitleAsset
* @brief A parent for classes representing a file containing subtitles
*
* This class holds a list of Subtitle objects which it can extract
* from the appropriate part of either an Interop or SMPTE XML file.
* Its subclasses InteropSubtitleAsset and SMPTESubtitleAsset handle the
* differences between the two types.
*/
-class SubtitleAsset : public Asset
+class TextAsset : public Asset
{
public:
- SubtitleAsset ();
- explicit SubtitleAsset (boost::filesystem::path file);
+ TextAsset();
+ explicit TextAsset(boost::filesystem::path file);
bool equals (
std::shared_ptr<const Asset>,
@@ -85,19 +85,19 @@ namespace order {
}
-/** @class SubtitleAsset
- * @brief A parent for classes representing a file containing subtitles
+/** @class TextAsset
+ * @brief A parent for classes representing a file containing subtitles or captions
*
* This class holds a list of Subtitle objects which it can extract
@@ -85,19 +85,19 @@ namespace order {
* This class holds a list of Subtitle objects which it can extract
* from the appropriate part of either an Interop or SMPTE XML file.
- * Its subclasses InteropSubtitleAsset and SMPTESubtitleAsset handle the
+ * Its subclasses InteropTextAsset and SMPTETextAsset handle the
* differences between the two types.
*/
diff --git a/src/verify.cc b/src/verify.cc
index b921375c..ee20e106 100644
--- a/src/verify.cc
+++ b/src/verify.cc
@@ -42,7 +42,7 @@
#include "dcp.h"
#include "exceptions.h"
#include "filesystem.h"
-#include "interop_subtitle_asset.h"
+#include "interop_text_asset.h"
#include "mono_j2k_picture_asset.h"
#include "mono_j2k_picture_frame.h"
#include "raw_convert.h"
@@ -53,7 +53,7 @@
#include "reel_sound_asset.h"
#include "reel_smpte_text_asset.h"
#include "reel_text_asset.h"
-#include "smpte_subtitle_asset.h"
+#include "smpte_text_asset.h"
#include "stereo_j2k_picture_asset.h"
#include "stereo_j2k_picture_frame.h"
#include "verify.h"
@@ -756,7 +756,7 @@ verify_closed_caption_reel(Context& context, shared_ptr<const ReelTextAsset> ree
void
verify_smpte_timed_text_asset (
Context& context,
- shared_ptr<const SMPTESubtitleAsset> asset,
+ shared_ptr<const SMPTETextAsset> asset,
optional<int64_t> reel_asset_duration
)
{
@@ -801,7 +801,7 @@ verify_smpte_timed_text_asset (
/** Verify Interop subtitle / CCAP stuff */
void
-verify_interop_text_asset(Context& context, shared_ptr<const InteropSubtitleAsset> asset)
+verify_interop_text_asset(Context& context, shared_ptr<const InteropTextAsset> asset)
{
if (asset->subtitles().empty()) {
context.error(VerificationNote::Code::MISSING_SUBTITLE, asset->id(), asset->file().get());
@@ -815,7 +815,7 @@ verify_interop_text_asset(Context& context, shared_ptr<const InteropSubtitleAsse
/** Verify SMPTE subtitle-only stuff */
void
-verify_smpte_subtitle_asset(Context& context, shared_ptr<const SMPTESubtitleAsset> asset)
+verify_smpte_subtitle_asset(Context& context, shared_ptr<const SMPTETextAsset> asset)
{
if (asset->language()) {
if (!context.subtitle_language) {
@@ -854,10 +854,10 @@ verify_smpte_subtitle_asset(Context& context, shared_ptr<const SMPTESubtitleAsse
/** Verify all subtitle stuff */
static void
-verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, optional<int64_t> reel_asset_duration)
+verify_subtitle_asset(Context& context, shared_ptr<const TextAsset> asset, optional<int64_t> reel_asset_duration)
{
context.stage("Checking subtitle XML", asset->file());
/* Note: we must not use SubtitleAsset::xml_as_string() here as that will mean the data on disk
* gets passed through libdcp which may clean up and therefore hide errors.
*/
if (asset->raw_xml()) {
@@ -866,7 +866,7 @@ verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, o
context.warning(VerificationNote::Code::MISSED_CHECK_OF_ENCRYPTED);
}
- auto namespace_count = [](shared_ptr<const SubtitleAsset> asset, string root_node) {
+ auto namespace_count = [](shared_ptr<const TextAsset> asset, string root_node) {
cxml::Document doc(root_node);
doc.read_string(asset->raw_xml().get());
auto root = dynamic_cast<xmlpp::Element*>(doc.node())->cobj();
@@ -877,7 +877,7 @@ verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, o
return count;
};
- auto interop = dynamic_pointer_cast<const InteropSubtitleAsset>(asset);
+ auto interop = dynamic_pointer_cast<const InteropTextAsset>(asset);
if (interop) {
verify_interop_text_asset(context, interop);
if (namespace_count(asset, "DCSubtitle") > 1) {
@@ -885,7 +885,7 @@ verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, o
}
}
- auto smpte = dynamic_pointer_cast<const SMPTESubtitleAsset>(asset);
+ auto smpte = dynamic_pointer_cast<const SMPTETextAsset>(asset);
if (smpte) {
verify_smpte_timed_text_asset(context, smpte, reel_asset_duration);
verify_smpte_subtitle_asset(context, smpte);
@@ -901,12 +901,12 @@ verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, o
static void
verify_closed_caption_asset (
Context& context,
- shared_ptr<const SubtitleAsset> asset,
+ shared_ptr<const TextAsset> asset,
optional<int64_t> reel_asset_duration
)
{
context.stage("Checking closed caption XML", asset->file());
/* Note: we must not use SubtitleAsset::xml_as_string() here as that will mean the data on disk
* gets passed through libdcp which may clean up and therefore hide errors.
*/
auto raw_xml = asset->raw_xml();
@@ -919,12 +919,12 @@ verify_closed_caption_asset (
context.warning(VerificationNote::Code::MISSED_CHECK_OF_ENCRYPTED);
}
- auto interop = dynamic_pointer_cast<const InteropSubtitleAsset>(asset);
+ auto interop = dynamic_pointer_cast<const InteropTextAsset>(asset);
if (interop) {
verify_interop_text_asset(context, interop);
}
- auto smpte = dynamic_pointer_cast<const SMPTESubtitleAsset>(asset);
+ auto smpte = dynamic_pointer_cast<const SMPTETextAsset>(asset);
if (smpte) {
verify_smpte_timed_text_asset(context, smpte, reel_asset_duration);
}
@@ -1202,7 +1202,7 @@ verify_closed_caption_details(Context& context, vector<shared_ptr<Reel>> reels)
void
dcp::verify_text_lines_and_characters(
- shared_ptr<const SubtitleAsset> asset,
+ shared_ptr<const TextAsset> asset,
int warning_length,
int error_length,
LinesCharactersResult* result
@@ -854,10 +854,10 @@ verify_smpte_subtitle_asset(Context& context, shared_ptr<const SMPTESubtitleAsse
{
context.stage("Checking subtitle XML", asset->file());
- /* Note: we must not use SubtitleAsset::xml_as_string() here as that will mean the data on disk
+ /* Note: we must not use TextAsset::xml_as_string() here as that will mean the data on disk
* gets passed through libdcp which may clean up and therefore hide errors.
*/
@@ -901,12 +901,12 @@ verify_subtitle_asset(Context& context, shared_ptr<const SubtitleAsset> asset, o
{
context.stage("Checking closed caption XML", asset->file());
- /* Note: we must not use SubtitleAsset::xml_as_string() here as that will mean the data on disk
+ /* Note: we must not use TextAsset::xml_as_string() here as that will mean the data on disk
* gets passed through libdcp which may clean up and therefore hide errors.
*/